CREATE TABLE users (
                       id INT(11) NOT NULL AUTO_INCREMENT COMMENT '用户ID',
                       username VARCHAR(100) NOT NULL UNIQUE COMMENT '用户名',
                       password VARCHAR(100) NOT NULL COMMENT '用户密码',
                       phone VARCHAR(15) NOT NULL UNIQUE COMMENT '用户手机号',
                       auth_status ENUM('unverified','pending', 'approved', 'rejected') DEFAULT 'unverified' COMMENT '认证状态：unverified=未提交，pending=待审核，approved=审核通过，rejected=审核拒绝',
                       created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '用户创建时间',
                       updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '用户更新时间',
                       PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='用户表，存储用户的基本信息';

CREATE TABLE enterprise_info (
                                 id INT(11) NOT NULL AUTO_INCREMENT COMMENT '企业信息ID',
                                 user_id BIGINT NOT NULL UNIQUE COMMENT '关联的用户ID',
                                 enterprise_name VARCHAR(150) NOT NULL UNIQUE COMMENT '企业名称',
                                 credit_code VARCHAR(150) NOT NULL UNIQUE COMMENT '企业统一信用代码',
                                 legal_person VARCHAR(150) NOT NULL COMMENT '法人代表',
                                 business_license VARCHAR(1024) NOT NULL COMMENT '营业执照存储路径',
                                 enterprise_contact VARCHAR(100) NOT NULL COMMENT '企业联系方式',
                                 created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '企业信息创建时间',
                                 updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '企业信息更新时间',
                                 PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='企业信息表，存储认证通过的企业详细信息';

CREATE TABLE enterprise_auth (
                                 id INT(11) NOT NULL AUTO_INCREMENT COMMENT '认证ID',
                                 user_id INT(11) NOT NULL COMMENT '关联的用户ID',
                                 enterprise_name VARCHAR(150) NOT NULL COMMENT '企业名称',
                                 credit_code VARCHAR(150) NOT NULL COMMENT '企业统一信用代码',
                                 legal_person VARCHAR(150) NOT NULL COMMENT '法人代表',
                                 business_license VARCHAR(1000) NOT NULL COMMENT '营业执照存储路径',
                                 enterprise_contact VARCHAR(100) NOT NULL COMMENT '企业联系方式',
                                 auth_status ENUM('unverified','pending', 'approved', 'rejected') DEFAULT 'unverified' COMMENT '认证状态：unverified=未提交，pending=待审核，approved=审核通过，rejected=审核拒绝',
                                 created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '认证创建时间',
                                 updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '认证更新时间',
                                 PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='企业认证表，存储企业认证的相关信息';
